import time


def get_now_date() -> str:
    """
    获取当前的日期, 格式为[2020-12-12].
    :return: 当前日期
    """
    now_time = time.localtime()
    return time.strftime('%Y-%m-%d', now_time)


def get_timestamp() -> int:
    """
    获取1970年到现在的秒数.
    :return: 自1970年1月1日 0点0分0秒以来的秒数.
    """
    now_time = time.time()
    return int(now_time)


def get_timestamp_str() -> str:
    """
    获取当前的时间, 格式为[2020-12-12 11:22:33].
    :return: 当前时间
    """
    now_time = time.localtime()
    return time.strftime('%Y-%m-%d %H:%M:%S', now_time)



import requests
from bs4 import BeautifulSoup as bs4
from requests.compat import urljoin

from licsber.auth.wisedu_utils import encrypt


def get_wisedu_session(url, no, pwd):
    """
    对接"金智教务统一登录系统"的API.
    :param url: 访问跳转登录页的url, 通常以authserver开头.
    :param no: 学号.
    :param pwd: 密码.
    :return: 一个登录完成的session, 可以继续访问接下来的网页.
    """
    s = requests.session()
    res = s.get(url)
    data = {
        "lt": None,
        "dllt": None,
        "execution": None,
        "_eventId": None,
        "rmShown": None,
        'pwdDefaultEncryptSalt': None
    }

    res = bs4(res.content, 'html.parser')

    salt = res.find('input', id='pwdDefaultEncryptSalt')['value']
    login_url = res.find('form', id='casLoginForm')['action']
    login_url = urljoin(url, login_url)

    for i in res.find_all('input'):
        if 'name' in i.attrs and i['name'] in data:
            data[i['name']] = i['value']

    data['username'] = no
    data['password'] = encrypt(pwd, salt)

    s.post(login_url, data=data)
    return s



import base64
import random

from Crypto.Cipher import AES


def pad(s: bytes, block_size: int) -> bytes:
    l = len(s)
    pad_num = block_size - (l % block_size)
    if pad_num == 0:
        pad_num = block_size
    pad_b = bytes([pad_num])
    return s + pad_b * pad_num


def aes_encrypt(s: str, key: str, iv='\0' * 16, coding='utf-8') -> str:
    key_b = key.encode(coding)
    iv_b = iv.encode(coding)
    raw_b = s.encode(coding)

    cipher = AES.new(key_b, AES.MODE_CBC, iv_b)
    padded = pad(raw_b, AES.block_size)
    encrypted = cipher.encrypt(padded)
    encoded = base64.b64encode(encrypted)
    return encoded.decode(coding)


def encrypt(pwd, salt):
    charsets = 'ABCDEFGHJKMNPQRSTWXYZabcdefhijkmnprstwxyz2345678'
    rnd_16 = ''.join(random.choice(charsets) for _ in range(16))
    rnd_64 = ''.join(random.choice(charsets) for _ in range(64))
    return aes_encrypt(rnd_64 + pwd, salt, rnd_16)



#!/usr/bin/env python
# coding: utf-8

import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name='licsber',
    version='1.0.0',
    author='Licsber',
    author_email='licsber@gmail.com',
    url='https://www.cnblogs.com/licsber/',
    description=u'个人娱乐工具箱.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    packages=setuptools.find_packages(),
    install_requires=[
        'pymongo',
        'requests',
        'beautifulsoup4',
        'pycryptodome',
    ],
    entry_points={
        'console_scripts': [
            'licsber=licsber:licsber',
            'count-dir=licsber:count_dir',
            'flatten_dir=licsber:flatten_dir',
            'memobird=licsber:memobird',
        ],
    },
    classifiers=[
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3 :: Only',
        'Operating System :: OS Independent',
    ],
    license='GPLv3',
)



import requests

from licsber.utils import get_timestamp_str
from licsber.utils import to_gbk_base64

URLS = {
    'set_user_bind': 'https://open.memobird.cn/home/setuserbind',
    'print_paper': 'https://open.memobird.cn/home/printpaper',
    'get_print_status': 'https://open.memobird.cn/home/getprintstatus'
}


def set_user_bind(ak: str, device_id: str, identifying='licsber') -> str:
    params = {
        'ak': ak,
        'timestamp': get_timestamp_str(),
        'memobirdID': device_id,
        'useridentifying': identifying,
    }
    res = requests.post(URLS['set_user_bind'], params=params).json()
    if res['showapi_res_code'] != 1:
        print(res)
        return ''
    return str(res['showapi_userid'])


def send_text_message(ak: str, device_id: str, text: str, userid=None) -> str:
    params = {
        'ak': ak,
        'timestamp': get_timestamp_str(),
        'printcontent': 'T:' + to_gbk_base64(text),
        'memobirdID': device_id,
        'userID': userid if userid else set_user_bind(ak, device_id, device_id),
    }
    res = requests.post(URLS['print_paper'], params=params).json()
    if res['showapi_res_code'] != 1:
        print(res)
        return ''
    return res['printcontentid']


def get_status(ak: str, print_id: str) -> str:
    params = {
        'ak': ak,
        'timestamp': get_timestamp_str(),
        'printcontentid': print_id,
    }
    res = requests.post(URLS['get_print_status'], params=params).json()
    if res['showapi_res_code'] != 1:
        print(res)
        return ''
    return res['printflag']
